# HOPE Smart Import


[![Test](https://github.com/unicef/hope-smart-import/actions/workflows/test.yml/badge.svg)](https://github.com/unicef/hope-smart-import/actions/workflows/test.yml)
[![Lint](https://github.com/unicef/hope-smart-import/actions/workflows/lint.yml/badge.svg)](https://github.com/unicef/hope-smart-import/actions/workflows/lint.yml)
[![Documentation](https://github.com/unicef/hope-smart-import/actions/workflows/docs.yml/badge.svg)](https://unicef.github.io/hope-smart-import/)
[![codecov](https://codecov.io/github/unicef/hope-smart-import/graph/badge.svg?token=L7HA5PJ45B)](https://codecov.io/github/unicef/hope-smart-import)
[![PyPI](https://img.shields.io/pypi/v/hope-smart-import)](https://pypi.org/project/hope-smart-import/)

[//]: # ([![PyPI - Python Version]&#40;https://img.shields.io/pypi/pyversions/hope-smart-import&#41;]&#40;https://pypi.org/project/hope-smart-import/&#41;)

Extremely simple application to create user customisable importing patterns.
